# Build with utimensat support. CMake only uses the parts that are
# implemented, but our CI setup doesn't know how to distinguish
%bcond_with allow_utimensat

%define major 3
%define minor 23
%define fix 1

Name: cmake
Version: %{major}.%{minor}.%{fix}
Release: 2
License: BSD-3-Clause 
Summary: Open Source Build System
Url: https://cmake.org

BuildRequires: libarchive-devel >= 3.3.3
BuildRequires: curl-devel
BuildRequires: expat-devel
BuildRequires: bzip2-devel
BuildRequires: ncurses-devel
BuildRequires: xz-devel
BuildRequires: zlib-devel
BuildRequires: libuv-devel

Requires: libarchive >= 3.3.3

Source0: https://cmake.org/files/v%{major}.%{minor}/cmake-%{version}.tar.gz

Source1: OS400.cmake
Source2: OS400-GNU-ASM.cmake
Source3: OS400-GNU-C.cmake
Source4: OS400-GNU.cmake
Source5: OS400-GNU-CXX.cmake
Source6: OS400-GNU-Fortran.cmake
Source7: OS400-XL-ASM.cmake
Source8: OS400-XL-C.cmake
Source9: OS400-XL.cmake
Source10: OS400-XL-CXX.cmake
Source11: OS400-XL-Fortran.cmake
Source12: OS400-XLClang.cmake
Source13: OS400-XLClang-C.cmake
Source14: OS400-XLClang-CXX.cmake
Source15: LinkSharedLibrary

Patch0: cmake-disallow-utimensat.patch
Patch3: cmake-GetLibraryNames.patch

%description
CMake is an open-source, cross-platform family of tools designed to build, test
and package software. CMake is used to control the software compilation process
using simple platform and compiler independent configuration files, and generate
native makefiles and workspaces that can be used in the compiler environment of
your choice. The suite of CMake tools were created by Kitware in response to the
need for a powerful, cross-platform build environment for open-source projects
such as ITK and VTK.

%prep
%setup -q

%if %{without allow_utimensat}
%patch0 -p1
%endif
%patch3 -p1

mkdir Modules/Platform/OS400
cp Modules/Platform/AIX/* Modules/Platform/OS400

cp \
  %{SOURCE1} \
  %{SOURCE2} \
  %{SOURCE3} \
  %{SOURCE4} \
  %{SOURCE5} \
  %{SOURCE6} \
  %{SOURCE7} \
  %{SOURCE8} \
  %{SOURCE9} \
  %{SOURCE10} \
  %{SOURCE11} \
  %{SOURCE12} \
  %{SOURCE13} \
  %{SOURCE14} \
    Modules/Platform
    
cp \
  %{SOURCE15} \
    Modules/Platform/OS400
chmod +x Modules/Platform/OS400/LinkSharedLibrary

%build

CFLAGS="%{optflags} -D_LINUX_SOURCE_COMPAT=1 -pthread"
CXXFLAGS="%{optflags} -D_LINUX_SOURCE_COMPAT=1 -pthread"
# Disbale debug info from C and CXX Flags
# Not building with debug info avoids
# ld: 0711-101 FATAL ERROR: Allocation of 41779544 bytes failed
# There is not enough memory available.
export CFLAGS=$(echo $CFLAGS | sed 's|-g ||')
export CXXFLAGS=$(echo $CXXFLAGS | sed 's|-g ||')
export LDFLAGS="-Wl,-bbigtoc -Wl,-bnortl -Wl,-blibsuff:so -pthread"
export CC="gcc"
export CXX="g++"


# When librhash, jsoncpp, and zstd built, we could
# add '--system-libs' and remove the rest of the
# individual --system-* lines, along with
# this comment. Otherwise, add individually
# as we get more function (for instance, '--system-jsoncpp')
./bootstrap \
  --prefix=%{_prefix} \
  --bindir=bin \
  --datadir=share/cmake-%{major}.%{minor} \
  --docdir=share/doc/cmake-%{major}.%{minor} \
  --mandir=share/man \
  --xdgdatadir=share \
  --system-curl \
  --system-expat \
  --system-zlib \
  --system-bzip2 \
  --system-liblzma \
  --system-libarchive \
  --system-libuv \
  # end

%make_build

%install

%make_install

# For now remove bash completion, emacs, and vim files
rm -r %{buildroot}%{_datadir}/bash-completion/completions
rm -r %{buildroot}%{_datadir}/emacs/site-lisp
rm -r %{buildroot}%{_datadir}/vim/vimfiles


%files
%defattr(-, qsys, *none)

%{_bindir}/ccmake
%{_bindir}/cmake
%{_bindir}/cpack
%{_bindir}/ctest

%{_docdir}/cmake-%{major}.%{minor}

%{_datadir}/aclocal/cmake.m4
%{_datadir}/cmake-%{major}.%{minor}

%changelog
* Thu Nov 02 2023 Kevin Adler <kadler@us.ibm.com> - 3.23.1
- Build with -bnortl to prevent symbol conflicts in the event libevent and
  libcurl are linked with different versions of OpenSSL

* Thu Apr 28 2022 Abdirahim Musse <abdirahim.musse@ibm.com> - 3.23.1
- Update CMake to 3.23.1

* Mon Dec 20 2021 Jason Hansen <stymie@us.ibm.com> - 3.16.9
- Upgrade to 3.16.9

* Wed Dec 15 2021 Jason Hansen <stymie@us.ibm.com> - 3.16.0
- Use SOVERSION to generate versioned shared objects

* Thu Jul 09 2020 Naveen Ram <naveen.ram@ibm.com> - 3.16.0
- Apply changes to generate versioned shared objects

* Fri May 15 2020 Jesse Gorzinski <jgorzins@us.ibm.com> - 3.16.0
- Fix "Error running link command: Permission denied"

* Tue Apr 28 2020 Kevin Adler <kadler@us.ibm.com> - 3.16.0
- Simplify IBM i platform files
- Add XLClang support

* Thu Apr 16 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 3.16.0
- Set import file prefix and suffix variables

* Tue Apr 14 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 3.16.0
- Activate symbol export/import

* Fri Feb 28 2020 Jesse Gorzinski <jgorzins@us.ibm.com> - 3.16.0
- Upgrade to 3.16.0
- Change to use system-provided libuv

* Wed Dec 04 2019 Kevin Adler <kadler@us.ibm.com> - 3.7.2
- Use SPDX license identifier
- Use bcond_with for conditionals
- Line wrap description to 80 columns
- General cleanup
- Add optflags to CFLAGS an CXXFLAGS since not using configure macro

* Tue Dec 3 2019 Kevin Adler <kadler@us.ibm.com> - 3.7.2
- Prevent using half-implemented utimensat APIs, fixing IBM i 7.2 build

* Wed Jul 25 2018 - Kevin Adler <kadler@us.ibm.com>
- Add AIX and PASE definitions for use in CMakeLists.txt
- Use -bbigtoc instead of -mminimal-toc

* Wed Jul 25 2018 - Kevin Adler <kadler@us.ibm.com>
- cmake needs -pthread for new libstdc++

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Add BuildRequires
- We have libarchive now, remove conditional flags

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove 64-bit GCC script workarounds
- OBJECT_MODE now always set by build and install macros

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Make cmake actually build

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove outdated TODO comments

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Use auto dependency resolution instead of requiring pase-libs

* Fri Sep 15 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix 64-bit build by setting OBJECT_MODE

* Mon Jun 05 2017 - Kevin Adler <kadler@us.ibm.com>
- Use make_build and make_install macros

* Thu Apr 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Add spec files
